# Gitless - a version control system built on top of Git.
# Copyright (c) 2013  Santiago Perez De Rosso.
# Licensed under GNU GPL, version 2.

"""gl untrack - Stop tracking changes to files."""


from . import file_cmd


parser = file_cmd.parser('stop tracking changes to files', 'untrack')
